diff --git a/security/src/main/java/org/springframework/ws/soap/security/AbstractWsSecurityInterceptor.java b/security/src/main/java/org/springframework/ws/soap/security/AbstractWsSecurityInterceptor.java
index fbf9276a..0cc62b05 100644
--- a/security/src/main/java/org/springframework/ws/soap/security/AbstractWsSecurityInterceptor.java
+++ b/security/src/main/java/org/springframework/ws/soap/security/AbstractWsSecurityInterceptor.java
@@ -41,25 +41,19 @@ public abstract class AbstractWsSecurityInterceptor implements SoapEndpointInter
private static final QName WS_SECURITY_NAME =
new QName("http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd", "Security");
- /**
- * Logger available to subclasses.
- */
+ /** Logger available to subclasses. */
protected final Log logger = LogFactory.getLog(getClass());
private boolean secureResponse = true;
private boolean validateRequest = true;
- /**
- * Indicates whether outgoing responsed are to be secured. Defaults to true.
- */
+ /** Indicates whether outgoing responsed are to be secured. Defaults to true. */
public void setSecureResponse(boolean secureResponse) {
this.secureResponse = secureResponse;
}
- /**
- * Indicates whether incoming request are to be validated. Defaults to true.
- */
+ /** Indicates whether incoming request are to be validated. Defaults to true. */
public void setValidateRequest(boolean validateRequest) {
this.validateRequest = validateRequest;
}
@@ -98,9 +92,7 @@ public abstract class AbstractWsSecurityInterceptor implements SoapEndpointInter
}
}
- /**
- * Returns true, i.e. faults are not secured.
- */
+ /** Returns true, i.e. faults are not secured. */
public boolean handleFault(MessageContext messageContext, Object endpoint) throws Exception {
return true;
}
@@ -142,8 +134,8 @@ public abstract class AbstractWsSecurityInterceptor implements SoapEndpointInter
}
/**
- * Abstract template method. Subclasses are required to validate the request contained in the given
- * SoapMessageContext, and replace the original request with the validated version.
+ * Abstract template method. Subclasses are required to validate the request contained in the given {@link
+ * SoapMessage}, and replace the original request with the validated version.
*
* @param soapMessage the soap message to validate
* @throws WsSecurityValidationException in case of validation errors
@@ -151,8 +143,8 @@ public abstract class AbstractWsSecurityInterceptor implements SoapEndpointInter
protected abstract void validateMessage(SoapMessage soapMessage) throws WsSecurityValidationException;
/**
- * Abstract template method. Subclasses are required to secure the response contained in the given
- * SoapMessageContext, and replace the original response with the secured version.
+ * Abstract template method. Subclasses are required to secure the response contained in the given {@link
+ * SoapMessage}, and replace the original response with the secured version.
*
* @param soapMessage the soap message to secure
* @throws WsSecuritySecurementException in case of securement errors
diff --git a/core/src/main/java/org/springframework/ws/server/endpoint/interceptor/AbstractValidatingInterceptor.java b/core/src/main/java/org/springframework/ws/server/endpoint/interceptor/AbstractValidatingInterceptor.java
index fc72be50..2140cf42 100644
--- a/core/src/main/java/org/springframework/ws/server/endpoint/interceptor/AbstractValidatingInterceptor.java
+++ b/core/src/main/java/org/springframework/ws/server/endpoint/interceptor/AbstractValidatingInterceptor.java
@@ -28,6 +28,8 @@ import org.springframework.util.StringUtils;
import org.springframework.ws.WebServiceMessage;
import org.springframework.ws.context.MessageContext;
import org.springframework.ws.server.EndpointInterceptor;
+import org.springframework.ws.soap.SoapFault;
+import org.springframework.ws.soap.SoapMessage;
import org.springframework.xml.transform.TransformerObjectSupport;
import org.springframework.xml.validation.XmlValidator;
import org.springframework.xml.validation.XmlValidatorFactory;
@@ -73,9 +75,7 @@ public abstract class AbstractValidatingInterceptor extends TransformerObjectSup
this.schemaLanguage = schemaLanguage;
}
- /**
- * Returns the schema resources to use for validation.
- */
+ /** Returns the schema resources to use for validation. */
public Resource[] getSchemas() {
return schemas;
}
@@ -101,16 +101,12 @@ public abstract class AbstractValidatingInterceptor extends TransformerObjectSup
setSchemas(new Resource[]{schema});
}
- /**
- * Indicates whether the request should be validated against the schema. Default is true.
- */
+ /** Indicates whether the request should be validated against the schema. Default is true. */
public void setValidateRequest(boolean validateRequest) {
this.validateRequest = validateRequest;
}
- /**
- * Indicates whether the response should be validated against the schema. Default is false.
- */
+ /** Indicates whether the response should be validated against the schema. Default is false. */
public void setValidateResponse(boolean validateResponse) {
this.validateResponse = validateResponse;
}
@@ -120,7 +116,7 @@ public abstract class AbstractValidatingInterceptor extends TransformerObjectSup
* validateRequest is set to true, which is the default.
*
true if the request is valid, or false if it isn't. Additionally, when the
* messageContext is a SoapMessageContext, a SOAP Fault is added as response.
*
* @param messageContext the message context
* @return true if the message is valid; false otherwise
@@ -120,7 +116,7 @@ public abstract class AbstractValidatingInterceptor extends TransformerObjectSup
*
true if the request is valid, or false if it isn't. Additionally, when the
- * messageContext is a SoapMessageContext, a SOAP Fault is added as response.
+ * request message is a {@link SoapMessage}, a {@link SoapFault} is added as response.
*
* @param messageContext the message context
diff --git a/core/src/main/java/org/springframework/ws/soap/server/endpoint/mapping/SoapActionEndpointMapping.java b/core/src/main/java/org/springframework/ws/soap/server/endpoint/mapping/SoapActionEndpointMapping.java
index 3609ea46..2bca365c 100644
--- a/core/src/main/java/org/springframework/ws/soap/server/endpoint/mapping/SoapActionEndpointMapping.java
+++ b/core/src/main/java/org/springframework/ws/soap/server/endpoint/mapping/SoapActionEndpointMapping.java
@@ -24,6 +24,7 @@ import org.springframework.ws.server.EndpointInvocationChain;
import org.springframework.ws.server.endpoint.mapping.AbstractMapBasedEndpointMapping;
import org.springframework.ws.soap.SoapEndpointMapping;
import org.springframework.ws.soap.SoapMessage;
+import org.springframework.ws.soap.axiom.AxiomSoapMessageFactory;
import org.springframework.ws.soap.server.SoapEndpointInvocationChain;
/**
@@ -42,8 +43,8 @@ import org.springframework.ws.soap.server.SoapEndpointInvocationChain;
*
* The syntax is SOAP_ACTION=ENDPOINT_BEAN_NAME.
*
* This endpoint mapping does not read from the request message, and therefore is more suitable for message contexts
* which directly read from the transport request (such as the AxiomSoapMessageContextFactory with the
* payloadCaching disabled).
*
* @author Arjen Poutsma
@@ -42,8 +43,8 @@ import org.springframework.ws.soap.server.SoapEndpointInvocationChain;
* The syntax is SOAP_ACTION=ENDPOINT_BEAN_NAME.
*
- * This endpoint mapping does not read from the request message, and therefore is more suitable for message contexts
- * which directly read from the transport request (such as the AxiomSoapMessageContextFactory with the
+ * This endpoint mapping does not read from the request message, and therefore is more suitable for message factories
+ * which directly read from the transport request (such as the {@link AxiomSoapMessageFactory} with the
* payloadCaching disabled).
*